summaryrefslogtreecommitdiffstats
path: root/kjsembed/bindings/image_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/bindings/image_imp.h')
-rw-r--r--kjsembed/bindings/image_imp.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kjsembed/bindings/image_imp.h b/kjsembed/bindings/image_imp.h
index 4104d3b5..39cb7031 100644
--- a/kjsembed/bindings/image_imp.h
+++ b/kjsembed/bindings/image_imp.h
@@ -24,15 +24,15 @@
#include <kjsembed/jsobjectproxy_imp.h>
-#include <qimage.h>
-#include <qpixmap.h>
+#include <tqimage.h>
+#include <tqpixmap.h>
namespace KJSEmbed {
namespace Bindings {
/**
* Methods for the QImage binding.
*
* @author Richard Moore, rich@kde.org
* @version $Id$
@@ -66,27 +66,27 @@ public:
private:
- QString filename() const;
- QString format() const;
+ TQString filename() const;
+ TQString format() const;
int width() const;
int height() const;
int depth() const;
bool isOk() const;
- QPixmap pixmap() const;
+ TQPixmap pixmap() const;
- bool load( const QString &filename );
- bool save( const QString &filename, const QString &fmt );
- void setFormat( const QString &fmt );
+ bool load( const TQString &filename );
+ bool save( const TQString &filename, const TQString &fmt );
+ void setFormat( const TQString &fmt );
void smoothScale( int w, int h );
void smoothScaleMin( int w, int h );
- void setPixmap( const QPixmap &pix );
+ void setPixmap( const TQPixmap &pix );
int mid;
- QImage img; // this is a temp!!!
- QString nm;
- QString fmt;
+ TQImage img; // this is a temp!!!
+ TQString nm;
+ TQString fmt;
};
} // namespace
@@ -24,15 +24,15 @@
namespace Bindings {
/**
- * Methods for the QImage binding.
+ * Methods for the TQImage binding.
*
* @author Richard Moore, rich@kde.org